Clazz.declarePackage("JS");
Clazz.declareInterface(JS, "TableCellRenderer");
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
